>
> This content is deprecated. See the latest version of this tutorial [here](https://docs.airnativeextensions.com/docs/tutorials/windows-appx-packaging-method2)
> 

# Windows Store Packaging: Method 2

**Create appx from your AIR executable**

This method involves running the `DesktopAppConverter` directly on the exe output from your AIR build.

This is probably the simplest method and produces an appx and self-signed certificate. 

You will have to install the certificate after each build to install the newly generated appx.



## Method

The output from your AIR application will be a directory, containing your `swf`, the `exe`, 
along with the AIR runtime, ANEs, DLLs, and all the other files packaged with your application.

This is the simplest method as you can use the output from the AIR SDK directly to create your Windows Store application (`appx`).

It is important that you only have files related to your project in the directory with your executable as anything in this directory will be copied to the final application. 

Here we use the `Installer` parameter to point to the root folder of your packaged app files. This is the folder containing the `AIRApp.exe` file generated by AIR.

```
DesktopAppConverter.exe 
    -Installer [PATH\TO\YOUR\AIR\OUTPUT] 
    -AppExecutable AIRApp.exe 
    -Destination [PATH\TO\OUTPUT] 
    -PackageName "[Package/Identity/Name]" 
    -PackageDisplayName "[DISPLAYNAME]" 
    -Publisher "CN=[Package/Identity/Publisher]"
    -PackagePublisherDisplayName "[Package/Properties/PublisherDisplayName]" 
    -AppDisplayName "[DISPLAYNAME]" 
    -Version [VERSION] 
    -MakeAppx 
    -Sign 
    -Verbose
```

- `-Installer` points to the root folder of your packaged AIR app files.
- `-AppExecutable` is the filename of your AIR application eg `AIRApp.exe`
- `-Destination` is where the DAC should produce the output of the command.
- `-MakeAppx` creates an .appx file that is the installation format of a Windows Store application.
- `PackageDisplayName`: Display package name for the application
- `AppDisplayName`: Display name for the application
- `-Sign` generates a certificate that you can install on your computer to test the generated package. When the final package is submitted to the Store, it is automatically signed by a trusted certificate during the process, so there is no need to do it later when you are ready to publish your application.
- `-Verbose` gives you better information while the conversion is happening.


Your app has a unique identity, assigned by the Store. In order to submit your application you will need to add some parameters setting information about your application from the developer dashboard. Identity details that can be found in the **App identity** section of your application in the developer dashboard. This information is required to correctly package your application for store submission however can be dummy values for local testing:

- `PackageName`: Package/Identity/Name
- `Publisher`: Package/Identity/Publisher
- `PackagePublisherDisplayName`: Package/Properties/PublisherDisplayName	


For example:

```
DesktopAppConverter.exe 
    -Installer C:\work\windowsstore\example\starling\out\TestWindowsStore
    -AppExecutable TestWindowsStore.exe 
    -Destination C:\work\windowsstore\example\starling\final
    -PackageName "distriqt.airnativeextensions" 
    -Publisher "CN=XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX" 
    -PackagePublisherDisplayName "distriqt" 
    -PackageDisplayName "airnativeextensions" 
    -AppDisplayName "airnativeextensions" 
    -Version 1.0.0.0 
    -MakeAppx 
    -Sign 
    -Verbose
 ```



## Testing the conversion

You can now install the `appx` application on your local machine. In order to do this you will need to install the certificate that was used to sign the application. This will called `auto-generated.cer` and be located in the output path alongside your `appx` application file. 


To install the certificate:

    - Double click cer file
    - Select "Install Certificate..."
    - Select "Local Machine"
    - Select "Place all certificates in the following store"
        - "Browse"
        - "Trusted Root Certification Authorities"

You can now install the application by double clicking the `appx` to launch the installer. This will install your application locally and have access to the UWP platform.



